@@ -1,12 +1,7 @@
-import hashlib
 from abc import ABC, abstractmethod
 from datetime import datetime
 from typing import ClassVar, Iterator, NamedTuple, Optional, Tuple, Type
 
-from funcy import cached_property
-
-from dql.storage import Storage
-
 
 class Bucket(NamedTuple):
     name: str
@@ -15,9 +10,6 @@ class Bucket(NamedTuple):
 
 
 class Client(ABC):
-    SHA_LIMIT = 12
-    ID_PREFIX = "dsrc_"
-    ID_LENGTH = SHA_LIMIT + len(ID_PREFIX)
     name: str
     protocol: ClassVar[str]
 
@@ -58,11 +50,3 @@ class Client(ABC):
     @abstractmethod
     def uri(self) -> str:
         ...
-
-    @cached_property
-    def storage_id(self):
-        sha = hashlib.sha256(self.uri.encode("utf-8")).hexdigest()
-        return Client.ID_PREFIX + sha[: Client.SHA_LIMIT]
-
-    def as_record(self) -> Storage:
-        return Storage(self.storage_id, self.protocol, self.name, None, None)
