@@ -4,7 +4,7 @@ from datetime import datetime
 from typing import Any, Dict, Iterable, Iterator, List, Optional, Tuple
 
 from dql.node import Node, NodeWithPath
-from dql.storage import AbstractStorage, Storage
+from dql.storage import Storage
 
 DB_FILE_NAME = "db"
 
@@ -63,16 +63,9 @@ class AbstractDataStorage(ABC):
         """Gets nodes from database by parent_id, with optional filtering"""
 
     @abstractmethod
-    def upsert_storage(self, uri: str) -> AbstractStorage:
+    def create_storage_if_not_registered(self, uri: str) -> None:
         """
-        Saves new storage if it doesn't exist in database, otherwise it updates
-        basic fields
-        """
-
-    @abstractmethod
-    def mark_storage_pending(self, storage: Storage) -> Storage:
-        """
-        Sets storage in pending state, which means it's ready for indexing
+        Saves new storage if it doesn't exist in database
         """
 
     @abstractmethod
@@ -160,6 +153,9 @@ class AbstractDataStorage(ABC):
         node: NodeWithPath,
         names=None,
         inames=None,
+        paths=None,
+        ipaths=None,
+        size=None,
         type=None,  # pylint: disable=redefined-builtin
         jmespath="",
     ) -> Iterable[NodeWithPath]:
