@@ -303,11 +303,21 @@ class Listing:
         node,
         names=None,
         inames=None,
+        paths=None,
+        ipaths=None,
+        size=None,
         type=None,  # pylint: disable=redefined-builtin
         jmespath=None,
     ):
         return self.data_storage.find(
-            node, names=names, inames=inames, type=type, jmespath=jmespath
+            node,
+            names=names,
+            inames=inames,
+            paths=paths,
+            ipaths=ipaths,
+            size=size,
+            type=type,
+            jmespath=jmespath,
         )
 
     def du(self, node):
