@@ -60,6 +60,10 @@ class AbstractNode:
     def name(self) -> Optional[str]:
         return self.name
 
+    @property
+    def owner_name(self) -> Optional[str]:
+        return self.owner_name
+
     @property
     def name_no_ext(self) -> str:
         if not self.name:
