@@ -1,9 +1,12 @@
+import posixpath
 from datetime import datetime
 
 import pytest
 
 from dql.catalog import Catalog
+from dql.data_storage import SQLiteDataStorage
 from dql.listing import Listing
+from dql.node import DirType
 
 # pylint: disable=redefined-outer-name
 
@@ -20,39 +23,51 @@ TREE = {
 }
 
 
-async def _tree_to_db(lst: Listing, tree: dict, dir_id: int = 0, path=""):
+async def _tree_to_db(lst: Listing, tree: dict, dir_id: int = 1, path=""):
     for k, v in tree.items():
         if k:
-            new_dir_id = await lst.insert_dir(dir_id, k, TS, path)
-            await _tree_to_db(lst, v, new_dir_id, path + "/" + k)
+            dir_path = posixpath.join(path, k)
+            new_dir_id = await lst.insert_dir(
+                dir_id, k, TS, posixpath.join(path, k)
+            )
+            await _tree_to_db(lst, v, new_dir_id, dir_path)
         else:
             for fname in v:
-                await lst.insert_file(dir_id, fname, TS)
+                await lst.insert_file(
+                    dir_id, fname, TS, posixpath.join(path, fname)
+                )
+
+
+@pytest.fixture
+def data_storage():
+    _data_storage = SQLiteDataStorage(db_file=":memory:")
+    yield _data_storage
+    _data_storage.db.execute("DROP TABLE IF EXISTS buckets")
 
 
 @pytest.fixture
 async def listing(data_storage):
     bkt = "s3://whatever"
     lst, _ = Catalog.enlist_source(data_storage, bkt, 1234, to_fetch=False)
-    await lst.insert_root()
-    await _tree_to_db(lst, TREE, 0)
+    await _tree_to_db(lst, TREE, await lst.insert_root())
     return lst
 
 
 async def test_resolve_path_in_root(listing):
     node = listing.resolve_path("dir1")
-    assert node.dir_id
+    assert node.dir_type == DirType.DIR
+    assert node.is_dir
     assert node.name == "dir1"
 
 
 async def test_path_resolving_nested(listing):
     node = listing.resolve_path("dir1/d2/file2.csv")
-    assert node.dir_id is None
+    assert node.dir_type == DirType.FILE
     assert node.name == "file2.csv"
     assert not node.is_dir
 
     node = listing.resolve_path("dir1/d2")
-    assert node.dir_id
+    assert node.dir_type == DirType.DIR
     assert node.is_dir
     assert node.name == "d2"
 
@@ -64,19 +79,22 @@ async def test_resolve_not_existing_path(listing):
 
 async def test_resolve_root(listing):
     node = listing.resolve_path("")
-    assert node.dir_id == 0
+    assert node.dir_type == DirType.ROOT
+    assert node.is_dir
     assert node.name == ""
 
 
 async def test_path_starts_with_slash(listing):
     node = listing.resolve_path("/dir1")
-    assert node.dir_id
+    assert node.dir_type == DirType.DIR
+    assert node.is_dir
     assert node.name == "dir1"
 
 
 async def test_dir_ends_with_slash(listing):
     node = listing.resolve_path("dir1/")
-    assert node.dir_id
+    assert node.dir_type == DirType.DIR
+    assert node.is_dir
     assert node.name == "dir1"
 
 
@@ -109,7 +127,8 @@ async def test_multilevel_expansion(listing):
 async def test_expand_root(listing):
     nodes = listing.expand_path("")
     assert len(nodes) == 1
-    assert nodes[0].dir_id == 0
+    assert nodes[0].dir_type == DirType.ROOT
+    assert nodes[0].is_dir
 
 
 async def test_list_dir(listing):
@@ -122,7 +141,9 @@ async def test_list_file(listing):
     file = listing.resolve_path("dir1/dataset.csv")
     nodes = list(listing.ls_path(file))
     _match_filenames(nodes, ["dataset.csv"])
-    assert nodes[0].dir_id == file.dir_id
+    assert nodes[0].id == file.id
+    assert nodes[0].dir_type == DirType.FILE
+    assert not nodes[0].is_dir
     assert nodes[0].name == file.name
 
 
